@@ -7,7 +7,7 @@
 #'        any words, Eurostat variable codes, and values available in the DSD \code{\link{search_eurostat_dsd}}. 
 #'        The default is \code{NULL}, in this case the whole dataset is returned via the bulk download. To filter by time see \code{date_filter} below.
 #'        If after filtering still the dataset has more observations than the limit per query via the API, then the bulk download is used to retrieve the data. 
-#' @param ignore.case a boolean with the default value \code{FALSE}, if the strings provided in \code{filters} shall be matched as is or the case can be ignored.  
+#' @param exact_match a boolean with the default value \code{TRUE}, if the strings provided in \code{filters} shall be matched exactly as it is or as a pattern. 
 #' @param date_filter a vector which can be numeric or character containing dates to filter the dataset.
 #'        If date filter applied only part of the dataset is downloaded through the API. 
 #'        The default is \code{NULL}, in this case the whole dataset is returned via the bulk download.
@@ -39,7 +39,8 @@
 #'        \url{http://ec.europa.eu/eurostat/data/database/information}.
 #' @param verbose A boolean with default \code{FALSE}, so detailed messages (for debugging) will not printed.
 #'         Can be set also with \code{options(restatapi_verbose=TRUE)}
-#' @param ... further argument for \code{\link{load_cfg}} function.
+#' @param ... further arguments to the for \code{\link{search_eurostat_dsd}} function like \code{ignore.case} 
+#'        with the default value \code{FALSE}, if the strings provided in \code{filters} shall be matched as is or the case can be ignored. 
 #' @export
 #' 
 #' @details Data sets are downloaded from the Eurostat Web Services 
@@ -53,19 +54,22 @@
 #' The datasets cached in memory (default) or can be stored in a temporary directory if \code{cache_dir} or \code{option(restatpi_cache_dir)} is defined.
 #' The cache can be emptied with \code{\link{clean_restatapi_cache}}.
 #' 
-#' The \code{id}, is a value from the \code{code} column of the table of contents (\code{\link{get_eurostat_toc}}), and can be searched for with the \code{\link{search_eurostat_toc}} function. The id value can be retrieved from the \href{http://ec.europa.eu/eurostat/data/database}{Eurostat database}
-#'  as well. The Eurostat
-#' database gives codes in the Data Navigation Tree after every dataset
-#' in parenthesis.
+#' The \code{id}, is a value from the \code{code} column of the table of contents (\code{\link{get_eurostat_toc}}), and can be searched 
+#' for with the \code{\link{search_eurostat_toc}} function. The id value can be retrieved from the \href{http://ec.europa.eu/eurostat/data/database}{Eurostat database}
+#'  as well. The Eurostat database gives codes in the Data Navigation Tree after every dataset in parenthesis.
 #' 
 #' Filtering can be done by the codes as described in the API documentation providing in the correct order and connecting with "." and "+". 
-#' If we do not know the codes we can filter based on words or by the mix of the two putting in a vector like \code{c("AT$","Belgium","persons","Total")}. Be careful that the filter is case sensitive, if you do not know exactly you can use the option \code{ignore.case=TRUE}, but it can include unwanted elements as well. 
-#' We do not have to worry about the correct order it will be put in the correct place based on the DSD. In the \code{filters} parameter regular expressions can be used as well. 
+#' If we do not know the codes we can filter based on words or by the mix of the two putting in a vector like \code{c("AT$","Belgium","persons","Total")}. 
+#' Be careful that the filter is case sensitive, if you do not know the code or label exactly you can use the option \code{ignore.case=TRUE} and \code{exact_match=FALSE}, 
+#' but in this case the results may include unwanted elements as well. In the \code{filters} parameter regular expressions can be used as well. 
+#' We do not have to worry about the correct order of the filter, it will be put in the correct place based on the DSD. 
+#' 
 #' 
 #' The \code{date_filter} shall be a string in the format yyyy[-mm][-dd]. The month and the day part is optional, but if we use the years and we have monthly frequency then all the data for the given year is retrieved.
 #' The string can be extended by adding the "<" or ">" to the beginning or to the end of the string. In this case the date filter is treated as range, and the date is used as a starting or end date. The data will include the observation of the start/end date.
-#' A single date range can be defined as well by concatenating two dates with the ":", e.g. "2016-08:2017-03-15". The dates can have different length. In this case cannot use the "<" or ">" characters.
-#' If there are multiple dates which is not a continuous range, it can be put in vector in any order like c("2016-08",2013-2015,"2017-07-01"). In this case, as well, it is  not possible to use the  "<" or ">" characters.      
+#' A single date range can be defined as well by concatenating two dates with the ":", e.g. \code{"2016-08:2017-03-15"}. As seen in the exemple the dates can have different length: one defined only at year/month level, the other by day level. 
+#' If a date range is defined with ":", it is not possible to use the "<" or ">" characters in the date filter.
+#' If there are multiple dates which is not a continuous range, it can be put in vector in any order like \code{c("2016-08",2013:2015,"2017-07-01")}. In this case, as well, it is  not possible to use the  "<" or ">" characters.      
 #'   
 #' @return a data.table. One column for each dimension in the data,
 #'         the time column for a time dimension, 
@@ -74,6 +78,9 @@
 #'         on particular time. 
 #' @seealso \code{\link{search_eurostat_toc}},\code{\link{search_eurostat_dsd}}
 #' @examples 
+#' load_cfg()
+#' eu<-get("cc",envir=.restatapi_env)
+#' 
 #' \dontshow{
 #' if ((parallel::detectCores()<2)|(Sys.info()[['sysname']]=='Windows')){
 #'    options(restatapi_cores=1)
@@ -91,9 +98,11 @@
 #' dt<-get_eurostat_data("agr_r_milkpr",date_filter=2008,keep_flags=TRUE)
 #' dt<-get_eurostat_data("avia_par_me",
 #'                       filters="BE$",
+#'                       exact_match=FALSE,
 #'                       date_filter=c(2016,"2017-03","2017-07-01"),
 #'                       select_freq="Q",
-#'                       label=TRUE)
+#'                       label=TRUE,
+#'                       name=FALSE)
 #' dt<-get_eurostat_data("agr_r_milkpr",
 #'                       filters=c("BE$","Hungary"),
 #'                       date_filter="2007-06<",
@@ -101,6 +110,9 @@
 #' dt<-get_eurostat_data("nama_10_a10_e",
 #'                       filters=c("Annual","EU28","Belgium","AT","Total","EMP_DC","person"),
 #'                       date_filter=c("2008",2002,2013:2018))
+#' dt<-get_eurostat_data("vit_t3",
+#'                       filters=c("EU28",eu$EA15,"HU$"),
+#'                       date_filter=c("2015",2007))
 #' dt<-get_eurostat_data("avia_par_me",
 #'                       filters="Q...ME_LYPG_HU_LHBP+ME_LYTV_UA_UKKK",
 #'                       date_filter=c("2016-08","2017-07-01"),
@@ -109,7 +121,7 @@
 
 get_eurostat_data <- function(id,
                          filters=NULL,
-                         ignore.case=FALSE,
+                         exact_match=TRUE,
                          date_filter=NULL,
                          label=FALSE,
                          select_freq=NULL,
@@ -125,7 +137,7 @@ get_eurostat_data <- function(id,
   restat<-rdat<-drop<-concept<-code<-FREQ<-N<-NULL
   verbose<-verbose|getOption("restatapi_verbose",FALSE)
   update_cache<-update_cache|getOption("restatapi_update",FALSE)
-  if (!(exists(".restatapi_env"))) {load_cfg(...)}
+  if (!(exists(".restatapi_env"))) {load_cfg()}
   cfg<-get("cfg",envir=.restatapi_env) 
   rav<-get("rav",envir=.restatapi_env)
   id<-tolower(id)
@@ -173,15 +185,16 @@ get_eurostat_data <- function(id,
         filters<-NULL
       } else {
         dsdorder<-unique(dsd$concept)[1:(length(unique(dsd$concept))-2)]
-        if((length(filters)>1)){   
-          ft<-do.call(rbind,lapply(filters,search_eurostat_dsd,dsd=dsd,ignore.case=ignore.case))[,2:3]
-          ft<-ft[order(match(ft$concept, dsdorder)),]
-          filters<-paste0(sapply(dsdorder,gen_ft,ft),collapse=".")
-        } else if (length(gregexpr("\\.",filters,perl=TRUE)[[1]])!=(length(dsdorder)-1)){
-          if (!is.null(nrow(search_eurostat_dsd(filters,dsd=dsd,ignore.case=ignore.case)))){
-            ft<-search_eurostat_dsd(filters,dsd=dsd,ignore.case=ignore.case)[,2:3]
+        if (length(gregexpr("\\.",filters,perl=TRUE)[[1]])!=(length(dsdorder)-1)){
+          if (exact_match){
+            filters<-paste0("^",filters,"$")
+            filters<-sub("^\\^{2}","\\^",sub("\\${2}$","\\$",filters))
+          }
+          ft<-do.call(rbind,lapply(filters,search_eurostat_dsd,dsd=dsd,...))
+          if ((ncol(ft)>1)){
+            ft<-ft[ft$code!=FALSE,2:3]
             ft<-ft[order(match(ft$concept, dsdorder)),]
-            filters<-paste0(sapply(dsdorder,gen_ft,ft),collapse=".")        
+            filters<-paste0(sapply(dsdorder,gen_ft,ft),collapse=".")  
           } else {
             filters<-NULL
           }
@@ -307,7 +320,7 @@ get_eurostat_data <- function(id,
           restat[,(drop):=NULL]
           data.table::setnames(restat,c("obsTime","obsValue"),c("time","values"))
           data.table::setnames(restat,colnames(restat),tolower(colnames(restat)))
-          restat<-data.table(restat,key=names(restat))
+          restat<-data.table(restat,key=names(restat),stringsAsFactors=stringsAsFactors)
           restat<-unique(restat)
           restat[order("time"),]
         }
@@ -387,7 +400,6 @@ get_eurostat_data <- function(id,
 gen_ft<-function(x,ft){
   paste0(ft$code[ft$concept==x],collapse="+")
 }
-
 check_tf<-function(x,tf){
   any(sapply(tf,grepl,x=x,perl=TRUE))
 }
